/**
 * Generate angular modules.
 * @function docAngularModules
 * @param {string[]} src - Source file name patterns.
 * @param {string} dest - Destination directories.
 * @param {options} [options] - Optional settings.
 * @param {string} [options.basedir=process.cwd()] - Base directory path.
 * @param {function} callback - Callback when done.
 */

"use strict";

var argx = require('argx'),
    path = require('path'),
    arrayreduce = require('arrayreduce'),
    execcli = require('execcli'),
    util = require('util'),
    hasbin = require('hasbin'),
    colorprint = require('colorprint');


/** @lends doAngularModules */
function doAngularModules(src, dest, options, callback) {
    var args = argx(arguments);
    callback = args.pop('function') || argx.noop;
    options = args.pop('object') || {};
    dest = args.pop('string');
    src = args.remain().reduce(arrayreduce.arrayConcat(), []).join(',');

    if (!dest) {
        callback(new Error('dest is required.'));
        return;
    }
    var bin = 'ngdoc-md';

    hasbin(bin, function (has) {
        if (!has) {
            var noBinError = new Error(
                util.format("`%s` not found. Try `npm install %s -g`.", bin, bin)
            );
            callback(noBinError);
            return;
        }
        execcli(bin, [src, dest, options], callback);
    });
}

module.exports = doAngularModules;